<?php

namespace App\Filament\Resources;

use App\Filament\Resources\SettingResource\Pages;
use App\Filament\Resources\SettingResource\RelationManagers;
use App\Models\Setting;
use Awcodes\Curator\Components\Forms\CuratorPicker;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Table;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\SoftDeletingScope;

class SettingResource extends Resource
{
    protected static ?string $model = Setting::class;

    protected static ?string $navigationIcon = 'heroicon-o-rectangle-stack';
    protected static ?string $navigationLabel = 'Setting';
    protected static ?string $modelLabel = 'Setting';

    protected static ?string $navigationGroup = 'Website Settings';

    protected static ?int $navigationSort = 7;

    public static function form(Form $form): Form
    {
        return $form
            ->schema([
                Forms\Components\TextInput::make('name')
                    ->maxLength(191),
                Forms\Components\Textarea::make('header_scripts')
                    ->maxLength(65535)
                    ->columnSpanFull(),
                Forms\Components\Textarea::make('body_scripts')
                    ->maxLength(65535)
                    ->columnSpanFull(),
                Forms\Components\Textarea::make('footer_scripts')
                    ->maxLength(65535)
                    ->columnSpanFull(),
                Forms\Components\Textarea::make('facebook')
                    ->maxLength(65535)
                    ->columnSpanFull(),
                Forms\Components\Textarea::make('twitter')
                    ->maxLength(65535)
                    ->columnSpanFull(),
                Forms\Components\Textarea::make('tiktok')
                    ->maxLength(65535)
                    ->columnSpanFull(),
                Forms\Components\Textarea::make('instagram')
                    ->maxLength(65535)
                    ->columnSpanFull(),
                Forms\Components\Textarea::make('linkedin')
                    ->maxLength(65535)
                    ->columnSpanFull(),
                Forms\Components\Textarea::make('youtube')
                    ->maxLength(65535)
                    ->columnSpanFull(),
                Forms\Components\Textarea::make('pinterest')
                    ->maxLength(65535)
                    ->columnSpanFull(),
                Forms\Components\Textarea::make('google_my_business')
                    ->maxLength(65535)
                    ->columnSpanFull(),
                Forms\Components\Textarea::make('direction_on_map')
                    ->maxLength(65535)
                    ->columnSpanFull(),
                CuratorPicker::make('image')
                    ->columnSpanFull(),
                Forms\Components\Textarea::make('address')
                    ->maxLength(65535)
                    ->columnSpanFull(),
                Forms\Components\Textarea::make('address_backup')
                    ->maxLength(65535)
                    ->columnSpanFull(),
                Forms\Components\TextInput::make('phone_number')
                    ->tel()
                    ->maxLength(191),
                Forms\Components\TextInput::make('email')
                    ->email()
                    ->maxLength(191),
                Forms\Components\TextInput::make('email_backup')
                    ->email()
                    ->maxLength(191),
                Forms\Components\TextInput::make('email_backup_one')
                    ->email()
                    ->maxLength(191),
                Forms\Components\TextInput::make('phone_number_backup')
                    ->tel()
                    ->maxLength(191),
                Forms\Components\TextInput::make('phone_number_backup_one')
                    ->tel()
                    ->maxLength(191),
                Forms\Components\TextInput::make('whatsapp')
                    ->maxLength(191),
                Forms\Components\TextInput::make('whatsapp_backup')
                    ->maxLength(191),
                Forms\Components\TextInput::make('whatsapp_backup_one')
                    ->maxLength(191),
                Forms\Components\Textarea::make('branch_one_address')
                    ->maxLength(65535)
                    ->columnSpanFull(),
                Forms\Components\TextInput::make('branch_one_phone_number')
                    ->tel()
                    ->maxLength(191),
                Forms\Components\TextInput::make('branch_one_email')
                    ->email()
                    ->maxLength(191),
                Forms\Components\TextInput::make('branch_one_email_backup')
                    ->email()
                    ->maxLength(191),
                Forms\Components\TextInput::make('branch_one_phone_number_backup')
                    ->tel()
                    ->maxLength(191),
                Forms\Components\TextInput::make('branch_one_whatsapp')
                    ->maxLength(191),
                Forms\Components\TextInput::make('branch_one_whatsapp_backup')
                    ->maxLength(191),
                CuratorPicker::make('logo')
                    ->columnSpanFull(),
                CuratorPicker::make('light_logo')
                    ->columnSpanFull(),
                CuratorPicker::make('favicon')
                    ->columnSpanFull(),
                Forms\Components\TextInput::make('title')
                    ->maxLength(191),
                Forms\Components\Textarea::make('meta_description')
                    ->maxLength(65535)
                    ->columnSpanFull(),
                Forms\Components\Textarea::make('keywords')
                    ->maxLength(65535)
                    ->columnSpanFull(),
                Forms\Components\Toggle::make('status')
                    ->required(),
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                Tables\Columns\TextColumn::make('name')
                    ->searchable(),
                Tables\Columns\TextColumn::make('phone_number')
                    ->searchable(),
                Tables\Columns\TextColumn::make('email')
                    ->searchable(),
                Tables\Columns\TextColumn::make('email_backup')
                    ->searchable(),
                Tables\Columns\TextColumn::make('email_backup_one')
                    ->searchable(),
                Tables\Columns\TextColumn::make('phone_number_backup')
                    ->searchable(),
                Tables\Columns\TextColumn::make('phone_number_backup_one')
                    ->searchable(),
                Tables\Columns\TextColumn::make('whatsapp')
                    ->searchable(),
                Tables\Columns\TextColumn::make('whatsapp_backup')
                    ->searchable(),
                Tables\Columns\TextColumn::make('whatsapp_backup_one')
                    ->searchable(),
                Tables\Columns\TextColumn::make('branch_one_phone_number')
                    ->searchable(),
                Tables\Columns\TextColumn::make('branch_one_email')
                    ->searchable(),
                Tables\Columns\TextColumn::make('branch_one_email_backup')
                    ->searchable(),
                Tables\Columns\TextColumn::make('branch_one_phone_number_backup')
                    ->searchable(),
                Tables\Columns\TextColumn::make('branch_one_whatsapp')
                    ->searchable(),
                Tables\Columns\TextColumn::make('branch_one_whatsapp_backup')
                    ->searchable(),
                Tables\Columns\TextColumn::make('title')
                    ->searchable(),
                Tables\Columns\IconColumn::make('status')
                    ->boolean(),
                Tables\Columns\TextColumn::make('created_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('updated_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
                Tables\Columns\TextColumn::make('deleted_at')
                    ->dateTime()
                    ->sortable()
                    ->toggleable(isToggledHiddenByDefault: true),
            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),
            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ]);
    }

    public static function getRelations(): array
    {
        return [
            //
        ];
    }

    public static function getPages(): array
    {
        return [
            'index' => Pages\ListSettings::route('/'),
            'create' => Pages\CreateSetting::route('/create'),
            'edit' => Pages\EditSetting::route('/{record}/edit'),
        ];
    }
}
