<?php

namespace App\Livewire\Frontend;

use App\Models\Setting;
use App\Models\Testimonial;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\URL;
use Illuminate\Support\Str;
use Livewire\Attributes\Rule;
use Livewire\Component;
use Livewire\WithFileUploads;
use Spatie\SchemaOrg\Schema;

class ShareTestimony extends Component
{
    use WithFileUploads;


    #[Rule('required')]
    public $your_name='';
    #[Rule('required|email')]
    public $email='';
    #[Rule('required')]
    public $phone_number='';
    #[Rule('required')]
    public $country='';
    #[Rule('required')]
    public $description='';
    #[Rule('required')]
    public $gallery;
    #[Rule('required')]
    public $name='';

    public function testimonyForm()
    {
        $url = URL::previous();
        $validated = $this->validate();
        $this->gallery->store(path: 'testimonies');
        Testimonial::create([

            'email' => $this->email,
            'description' => $this->description,
            'your_name' => $this->your_name,
            'name' => $this->name,
            'slug' => Str::slug($this->name).'-'.Str::random(),
            'phone_number' => $this->phone_number,
            'country' => $this->country,
            'gallery'=>$this->gallery,

        ]);

        //send email
        $settings = Setting::first();
         Mail::to($this->email)->send(new \App\Mail\UserTestimony($validated));
         Mail::to($settings->email)->send(new \App\Mail\AdminTestimony($validated));

        $url = URL::previous();
        $this->reset();
        flash()->addSuccess('Testimony sent Successfully', 'Successful');
        //session()->flash('register-message', 'You have booked property Successfully');
        $this->redirect($url);



    }



    public function render()
    {
        $settings = Setting::first();
        seo()
            ->title($title = "Share Your Testimony")
            ->description($description = 'Lorem ipsum...')
            ->canonical($url = URL::current())
            ->addSchema(
                Schema::webPage()
                    ->name($title)
                    ->description($description)
                    ->url($url)
                    ->author(Schema::organization()->name($title))
            );
        return view('livewire.frontend.share-testimony',
            [
                'settings' => $settings,
                'title' => $title

            ])->extends('livewire.layouts.main-layout',
            [

                'settings' => $settings,
                'title' => $title,
            ]);
    }
}
