<?php

namespace App\Livewire;

use App\Models\Enquiry;
use App\Models\Setting;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\URL;
use Livewire\Attributes\Rule;
use Livewire\Component;
use Spatie\SchemaOrg\Schema;

class IndexContact extends Component
{

    #[Rule('required')]
    public $name='';
    #[Rule('required|email')]
    public $email='';
    #[Rule('required')]
    public $phone_number='';
    #[Rule('required')]
    public $subject='';
    #[Rule('required')]
    public $message='';
    public function enquiry()
    {
        $url = URL::previous();
        $validated = $this->validate();
        Enquiry::create([

            'email' => $this->email,
            'message' => $this->message,
            'name' => $this->name,
            'phone_number' => $this->phone_number,
            'subject' => $this->subject

        ]);
        //send email
        $settings = Setting::first();

        Mail::to($this->email)->send(new \App\Mail\UserEnquiry($validated));
        Mail::to($settings->email)->send(new \App\Mail\AdminEnquiry($validated));

        $url = URL::previous();
        $this->reset();
        flash()->addSuccess('Message sent Successfully', 'Successful');
        //session()->flash('register-message', 'You have booked property Successfully');
        $this->redirect($url);



    }

    public function render()
    {
        $settings = Setting::first();
        seo()
            ->title($title = "Our Contacts")
            ->description($description = 'Lorem ipsum...')
            ->canonical($url = URL::current())
            ->addSchema(
                Schema::webPage()
                    ->name($title)
                    ->description($description)
                    ->url($url)
                    ->author(Schema::organization()->name($title))
            );
        return view('livewire.index-contact',
            [
                'settings' => $settings,
                'title' => $title

            ])->extends('livewire.layouts.main-layout',
            [

                'settings' => $settings,
                'title' => $title,
            ]);
    }
}
