<?php

namespace App\Livewire;

use App\Models\Offering;
use App\Models\Setting;
use Illuminate\Support\Facades\URL;
use Illuminate\Support\Str;
use IntaSend\IntaSendPHP\Checkout;
use IntaSend\IntaSendPHP\Collection;
use IntaSend\IntaSendPHP\Customer;
use Livewire\Attributes\Rule;
use Livewire\Component;
use Spatie\SchemaOrg\Schema;

class IndexOffering extends Component
{
    #[Rule('required')]
    public $amount = 100;
    #[Rule('required')]
    public $currency;
    #[Rule('required')]
    public $name;
    #[Rule('required|email')]
    public $email;
    #[Rule('required')]
    public $phone_number;


    public function offeringForm(){

        $validated = $this->validate();
        //create
        $credentials = [
            'publishable_key' => env('INTASEND_KEY'),
            'token' => env('INTASEND_TOKEN'),
            'test' => env('INTASEND_ENVIRONMENT', true),
        ];
        $invoice = Offering::latest()->first();
        if (empty($invoice)) {
            $invoice_id = 'DON-0001';
        } else {
            $invoice_id = 'DON-' . (str_pad(($invoice->id + 1), 4, '0', STR_PAD_LEFT));
        }
        //to use later
        $order = rand(1000, 9999) . strtoupper(Str::random(4));


        //redirect to pay
        $names = explode(' ', $this->name, 2);
        $fname = $names[0];
        $lname = $names[1];
        //on success to this URL

        $customer = new Customer();
        $customer->first_name = $fname;
        $customer->last_name = $lname;
        $customer->email = $this->email;
       // $customer->country = "KE";

        $amount = $this->amount;
        $currency = $this->currency;
        $ref_order_number = $order;

// Add your website and redirect url where the user will be redirected on success
        $host = "https://church.businesstools.co.ke";
        //call back to check success & invoice = true paid on the URL UPDATE the call back
       // $callback_url = route('frontend.offering-success',['offering'=>$order]);
       $callback_url = route('frontend.payment');
        $redirect_url =$callback_url;

        $card_tarrif = "BUSINESS-PAYS";
        $mobile_tarrif = "BUSINESS-PAYS";
        $wallet_id=null;

        $checkout = new Checkout();
        $checkout->init($credentials);
        $resp = $checkout->create($amount, $currency, $customer, $host, $redirect_url, $ref_order_number, $comment = null, $method = null, $card_tarrif, $mobile_tarrif, $wallet_id);
        info(array($resp->id));
        $saved = Offering::create([
            'email' => $this->email,
            'name' => $this->name,
            //phone number
            'phone_number' => $this->phone_number,
            'currency' => $this->currency,
            'amount' => $this->amount,
            // invoice  //invoice ID
            'invoice_id' => $invoice_id,
            'order_id' => $order,
            'payer_id' => $resp->id,
            'payment_method' => "INTASEND",

        ]);


       // dd($resp);
        $url =  $resp->url;
        $this->reset();
      //  flash()->addSuccess('Successful', 'Your request was successfully received');
        //session()->flash('register-message', 'You have booked property Successfully');
        $this->redirect($url);
        //wait for redirect
     /*  sleep(20);
       if($resp['invoice']['state'] == 'COMPLETE'){
           flash()->addSuccess('Successful', 'Your request was successfully received');
             }*/

    }


    public function render()
    {
        $settings = Setting::first();
        seo()
            ->title($title = "Giving and Offerings")
            ->description($description = 'Lorem ipsum...')
            ->canonical($url = URL::current())
            ->addSchema(
                Schema::webPage()
                    ->name($title)
                    ->description($description)
                    ->url($url)
                    ->author(Schema::organization()->name($title))
            );
        return view('livewire.index-offering',
            [
                'settings' => $settings,
                'title' => $title

            ])->extends('livewire.layouts.main-layout',
            [

                'settings' => $settings,
                'title' => $title,
            ]);
    }
}
